@@ -233,7 +233,7 @@ class Commands:
     def broadcast(self, tx, timeout=10):
         """Broadcast a transaction to the network. """
         t = Transaction(tx)
-        return self.network.broadcast(str(t), timeout)
+        return self.network.broadcast(t, timeout)
 
     @command('')
     def createmultisig(self, num, pubkeys):
@@ -614,6 +614,11 @@ class Commands:
         self.network.send([('blockchain.address.subscribe', [address])], callback)
         return True
 
+    @command('')
+    def help(self):
+        # for the python console
+        return sorted(known_commands.keys())
+
 param_descriptions = {
     'privkey': 'Private key. Type \'?\' to get a prompt.',
     'destination': 'Bitcoin address, contact or alias',
